'''
Created by auto_sdk on 2021.11.23
'''
from seven_top.top.api.base import RestApi
class CrmPointAvailableGetRequest(RestApi):
    def __init__(self,domain='gw.api.taobao.com',port=80):
        RestApi.__init__(self,domain, port)
        self.buyer_nick = None
        self.mix_nick = None
        self.open_uid = None

    def getapiname(self):
        return 'taobao.crm.point.available.get'



'''
Created by auto_sdk on 2018.07.26
'''
from seven_top.top.api.base import RestApi
class AlibabaAliqinTaSmsNumQueryRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.biz_id = None
		self.current_page = None
		self.page_size = None
		self.query_date = None
		self.rec_num = None

	def getapiname(self):
		return 'alibaba.aliqin.ta.sms.num.query'



'''
Created by auto_sdk on 2020.09.17
'''
from seven_top.top.api.base import RestApi
class MiniappCloudMongoInsertRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.record = None
		self.collection = None
		self.env = None

	def getapiname(self):
		return 'taobao.miniapp.cloud.mongo.insert'



'''
Created by auto_sdk on 2021.07.22
'''
from seven_top.top.api.base import RestApi
class AlibabaLafiteSellerActivityListRequest(RestApi):
    def __init__(self,domain='gw.api.taobao.com',port=80):
        RestApi.__init__(self,domain, port)
        self.query = None

    def getapiname(self):
        return 'alibaba.lafite.seller.activity.list'



'''
Created by auto_sdk on 2021.01.12
'''
from seven_top.top.api.base import RestApi
class OpentradeGroupSyncRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.allow_type = None
		self.allow_white_list = None
		self.discount_price = None
		self.end_time = None
		self.expiration = None
		self.fail_process = None
		self.goal = None
		self.group_activity_id = None
		self.group_type = None
		self.item_id = None
		self.open_limit = None
		self.start_time = None

	def getapiname(self):
		return 'taobao.opentrade.group.sync'



'''
Created by auto_sdk on 2022.09.19
'''
from seven_top.top.api.base import RestApi
class TmallMeiCrmMemberSyncRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.extend = None
		self.level = None
		self.level_expire_time = None
		self.level_point = None
		self.level_type = None
		self.mix_nick = None
		self.mobile = None
		self.nick = None
		self.point = None
		self.version = None

	def getapiname(self):
		return 'tmall.mei.crm.member.sync'



'''
Created by auto_sdk on 2022.03.30
'''
from seven_top.top.api.base import RestApi
class OpencrmCardEstimateNumberRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.crowd_inst_id = None
		self.filter_black_list = None
		self.mobile_acquisition_rule = None
		self.template_id = None

	def getapiname(self):
		return 'taobao.opencrm.card.estimate.number'



'''
Created by auto_sdk on 2021.09.14
'''
from seven_top.top.api.base import RestApi
class QmTbCrmMembersSearchPrivyGet(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.page_size = 10
		self.page_index = 1
		# self.buyer_nick = ""
		# self.grade = 0
		# self.ouid = ""
		# self.last_trade_time_min = ""
		# self.last_trade_time_max = ""
		# self.trade_amount_min = ""
		# self.trade_amount_max = ""
		# self.trade_count_min = 0
		# self.trade_count_max = 0
		# self.relation_source = 0
		# self.group_id = 0
		self.access_permit = ""

	def getapiname(self):
		return 'tb.crm.members.search.privy.get'


'''
Created by auto_sdk on 2022.11.17
'''
from seven_top.top.api.base import RestApi
class MiniappInteractBenefitItemGetRequest(RestApi):
    def __init__(self,domain='gw.api.taobao.com',port=80):
        RestApi.__init__(self,domain, port)
        self.mini_app_seller_strategy_benefit_item_bind_request = None

    def getapiname(self):
        return 'taobao.miniapp.interact.benefit.item.get'



'''
Created by auto_sdk on 2018.07.27
'''
from seven_top.top.api.base import RestApi
class RefundMessagesGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.fields = None
		self.page_no = None
		self.page_size = None
		self.refund_id = None
		self.refund_phase = None

	def getapiname(self):
		return 'taobao.refund.messages.get'



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-06-03 09:55:46
@LastEditTime: 2024-06-03 09:56:38
@LastEditors: HuangJianYi
@Description: 
"""
'''
Created by auto_sdk on 2024.05.22
'''
from seven_top.top.api.base import RestApi
class OpenmemberActivitySmsJoinRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.member_join_ext_dto = None

	def getapiname(self):
		return 'taobao.openmember.activity.sms.join'



'''
Created by auto_sdk on 2022.09.20
'''
from seven_top.top.api.base import RestApi
class JushitaJdpUsersGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.end_modified = None
		self.page_no = None
		self.page_size = None
		self.start_modified = None
		self.target_appkey = None
		self.user_id = None

	def getapiname(self):
		return 'taobao.jushita.jdp.users.get'



'''
Created by auto_sdk on 2022.08.05
'''
from seven_top.top.api.base import RestApi
class CrmMembersGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.buyer_nick = None
		self.current_page = None
		self.grade = None
		self.max_last_trade_time = None
		self.max_trade_amount = None
		self.max_trade_count = None
		self.min_last_trade_time = None
		self.min_trade_amount = None
		self.min_trade_count = None
		self.open_uid = None
		self.page_size = None

	def getapiname(self):
		return 'taobao.crm.members.get'



'''
Created by auto_sdk on 2021.11.23
'''
from seven_top.top.api.base import RestApi
class OpencrmCtagUploadPrivyRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.encrypt = None
		self.id = None
		self.members = None
		self.open_ids = None
		self.status = None
		self.type = None

	def getapiname(self):
		return 'taobao.opencrm.ctag.upload.privy'



'''
Created by auto_sdk on 2021.01.14
'''
from seven_top.top.api.base import RestApi
class JstSmsMessageDirectBatchsendRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.extend_num = None
		self.rec_num = None
		self.sign_name = None
		self.sms_content = None
		self.sms_template_code = None
		self.task_code = None
		self.task_sign = None
		self.url = None

	def getapiname(self):
		return 'taobao.jst.sms.message.direct.batchsend'



'''
Created by auto_sdk on 2021.01.04
'''
from seven_top.top.api.base import RestApi
class JstSmsMessageShorturlCreateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.batch_number = None
		self.need_https_prefix = None
		self.tag = None
		self.url = None

	def getapiname(self):
		return 'taobao.jst.sms.message.shorturl.create'



'''
Created by auto_sdk on 2019.10.31
'''
from seven_top.top.api.base import RestApi
class SkusCustomGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.fields = None
		self.outer_id = None

	def getapiname(self):
		return 'taobao.skus.custom.get'



'''
Created by auto_sdk on 2018.07.27
'''
from seven_top.top.api.base import RestApi
class RefundMessageAddRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.content = None
		self.image = None
		self.refund_id = None

	def getapiname(self):
		return 'taobao.refund.message.add'

	def getMultipartParas(self):
		return ['image']



'''
Created by auto_sdk on 2022.03.24
'''
from seven_top.top.api.base import RestApi
class OpencrmRuleExeruleRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.biz_order_id = None
		self.biz_type = None
		self.buyer_nick = None
		self.end_date_by_year = None
		self.exclude_item = None
		self.freight_fee = None
		self.item_amount_map = None
		self.month_end_day = None
		self.month_start_day = None
		self.open_uid = None
		self.param_map = None
		self.query_end_date = None
		self.query_start_date = None
		self.special_item = None
		self.specify_amount = None
		self.specify_amount_by_date = None
		self.specify_amount_by_day = None
		self.specify_count_by_date = None
		self.specify_count_by_day = None
		self.start_date_by_year = None
		self.stat_type = None
		self.total_item_set = None
		self.total_pay_amount = None
		self.user_id = None
		self.week_end_day = None
		self.week_start_day = None

	def getapiname(self):
		return 'taobao.opencrm.rule.exerule'



'''
Created by auto_sdk on 2020.08.12
'''
from seven_top.top.api.base import RestApi
class OpentradeSpecialUsersQueryRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.item_id = None
		self.open_user_ids = None
		self.page_index = None
		self.page_size = None
		self.sku_id = None
		self.status = None

	def getapiname(self):
		return 'taobao.opentrade.special.users.query'



'''
Created by auto_sdk on 2021.11.23
'''
from seven_top.top.api.base import RestApi
class OpencrmRuleAddRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.biz_type = None
		self.grade_code = None
		self.rule_desc = None
		self.rule_name = None
		self.rule_text = None
		self.rule_type = None
		self.total_flag = None

	def getapiname(self):
		return 'taobao.opencrm.rule.add'



'''
Created by auto_sdk on 2022.09.19
'''
from seven_top.top.api.base import RestApi
class JushitaJdpUserAddRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.history_days = None
		self.host_ip = None
		self.host_name = None
		self.rds_name = None
		self.topics = None

	def getapiname(self):
		return 'taobao.jushita.jdp.user.add'



# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-07-08 10:14:46
@LastEditTime: 2024-02-01 11:45:55
@LastEditors: HuangJianYi
:Description: 
"""

import http.client as httplib
import urllib
import time
import hashlib
import json
import itertools
import mimetypes
from seven_top import top
'''
定义一些系统变量
'''

SYSTEM_GENERATE_VERSION = "taobao-sdk-python-20200811"

P_APPKEY = "app_key"
P_API = "method"
P_SESSION = "session"
P_ACCESS_TOKEN = "access_token"
P_VERSION = "v"
P_FORMAT = "format"
P_TIMESTAMP = "timestamp"
P_SIGN = "sign"
P_SIGN_METHOD = "sign_method"
P_PARTNER_ID = "partner_id"
P_TARGET_APPKEY = "target_app_key"

P_CODE = 'code'
P_SUB_CODE = 'sub_code'
P_MSG = 'msg'
P_SUB_MSG = 'sub_msg'

N_REST = '/router/rest'
QM_REST = '/router/qm'


def sign(secret, parameters):
    #===========================================================================
    # '''签名方法
    # @param secret: 签名需要的密钥
    # @param parameters: 支持字典和string两种
    # '''
    #===========================================================================
    # 如果parameters 是字典类的话
    if hasattr(parameters, "items"):
        keys = list(parameters.keys())
        keys.sort()

        parameters = "%s%s%s" % (secret, str().join('%s%s' % (key, parameters[key]) for key in keys), secret)
    sign = hashlib.md5(parameters.encode("utf8")).hexdigest().upper()
    return sign


def mixStr(pstr):
    if (isinstance(pstr, str)):
        return pstr
    elif (isinstance(pstr, bytes)):
        return pstr.encode('utf-8')
    else:
        return str(pstr)


class FileItem(object):
    def __init__(self, filename=None, content=None):
        self.filename = filename
        self.content = content


class MultiPartForm(object):
    """Accumulate the data to be used when posting a form."""
    def __init__(self):
        self.form_fields = []
        self.files = []
        self.boundary = "PYTHON_SDK_BOUNDARY"
        return

    def get_content_type(self):
        return 'multipart/form-data; boundary=%s' % self.boundary

    def add_field(self, name, value):
        """Add a simple field to the form data."""
        self.form_fields.append((name, str(value)))
        return

    def add_file(self, fieldname, filename, fileHandle, mimetype=None):
        """Add a file to be uploaded."""
        body = fileHandle.read()
        if mimetype is None:
            mimetype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
        self.files.append((mixStr(fieldname), mixStr(filename), mixStr(mimetype), mixStr(body)))
        return

    def __str__(self):
        """Return a string representing the form data, including attached files."""
        # Build a list of lists, each containing "lines" of the
        # request.  Each part is separated by a boundary string.
        # Once the list is built, return a string where each
        # line is separated by '\r\n'.
        parts = []
        part_boundary = '--' + self.boundary

        # Add the form fields
        parts.extend([
            part_boundary,
            'Content-Disposition: form-data; name="%s"' % name,
            'Content-Type: text/plain; charset=UTF-8',
            '',
            value,
        ] for name, value in self.form_fields)

        # Add the files to upload
        parts.extend(
            [ part_boundary,
              'Content-Disposition: file; name="%s"; filename="%s"' % \
                 (field_name, filename),
              'Content-Type: %s' % content_type,
              'Content-Transfer-Encoding: binary',
              '',
              body,
            ]
            for field_name, filename, content_type, body in self.files
            )

        # Flatten the list and add closing boundary marker,
        # then return CR+LF separated data
        flattened = list(itertools.chain(*parts))
        flattened.append('--' + self.boundary + '--')
        flattened.append('')
        return '\r\n'.join(flattened)


class TopException(Exception):
    #===========================================================================
    # 业务异常类
    #===========================================================================
    def __init__(self):
        self.errorcode = None
        self.message = None
        self.subcode = None
        self.submsg = None
        self.application_host = None
        self.service_host = None

    def __str__(self, *args, **kwargs):
        sb = "errorcode=" + mixStr(self.errorcode) +\
            " message=" + mixStr(self.message) +\
            " subcode=" + mixStr(self.subcode) +\
            " submsg=" + mixStr(self.submsg) +\
            " application_host=" + mixStr(self.application_host) +\
            " service_host=" + mixStr(self.service_host)
        return sb


class RequestException(Exception):
    #===========================================================================
    # 请求连接异常类
    #===========================================================================
    pass


class RestApi(object):
    #===========================================================================
    # Rest api的基类
    #===========================================================================

    def __init__(self, domain='gw.api.taobao.com', port=80):
        #=======================================================================
        # 初始化基类
        # Args @param domain: 请求的域名或者ip
        #      @param port: 请求的端口
        #=======================================================================
        self.__domain = domain
        self.__port = port
        self.__httpmethod = "POST"
        if (top.getDefaultAppInfo()):
            self.__app_key = top.getDefaultAppInfo().appkey
            self.__secret = top.getDefaultAppInfo().secret

    def get_request_header(self):
        return {
            'Content-type': 'application/x-www-form-urlencoded;charset=UTF-8',
            "Cache-Control": "no-cache",
            "Connection": "Keep-Alive",
        }

    def set_app_info(self, appinfo):
        #=======================================================================
        # 设置请求的app信息
        # @param appinfo: import top
        #                 appinfo top.appinfo(appkey,secret)
        #=======================================================================
        self.__app_key = appinfo.appkey
        self.__secret = appinfo.secret

    def getapiname(self):
        return ""

    def getMultipartParas(self):
        return []

    def getTranslateParas(self):
        return {}

    def _check_requst(self):
        pass

    def getResponse(self, authrize=None, timeout=30, **kwargs):
        #=======================================================================
        # 获取response结果
        #=======================================================================
        if (self.__port == 443):
            connection = httplib.HTTPSConnection(host=self.__domain, port=self.__port, timeout=timeout)
        else:
            connection = httplib.HTTPConnection(host=self.__domain, port=self.__port, timeout=timeout)
        sys_parameters = {
            P_FORMAT: 'json',
            P_APPKEY: self.__app_key,
            P_SIGN_METHOD: "md5",
            P_VERSION: '2.0',
            P_TIMESTAMP: str(int(time.time() * 1000)),
            P_PARTNER_ID: SYSTEM_GENERATE_VERSION,
            P_API: self.getapiname(),
        }
        if kwargs.get("domain", "") == "qm" and kwargs.get("target_app_key", ""):
            sys_parameters[P_TARGET_APPKEY] = kwargs.get("target_app_key")
        if authrize is not None:
            sys_parameters[P_SESSION] = authrize
        application_parameter = self.getApplicationParameters()
        sign_parameter = sys_parameters.copy()
        sign_parameter.update(application_parameter)
        sys_parameters[P_SIGN] = sign(self.__secret, sign_parameter)
        connection.connect()

        header = self.get_request_header()
        if (self.getMultipartParas()):
            form = MultiPartForm()
            for key, value in application_parameter.items():
                form.add_field(key, value)
            for key in self.getMultipartParas():
                fileitem = getattr(self, key)
                if (fileitem and isinstance(fileitem, FileItem)):
                    form.add_file(key, fileitem.filename, fileitem.content)
            body = str(form)
            header['Content-type'] = form.get_content_type()
        else:
            body = urllib.parse.urlencode(application_parameter)
        rest = QM_REST if kwargs.get("domain", "") == "qm" else N_REST
        url = rest + "?" + urllib.parse.urlencode(sys_parameters)
        connection.request(self.__httpmethod, url, body=body, headers=header)
        response = connection.getresponse()
        if response.status != 200:
            raise RequestException('invalid http status ' + str(response.status) + ',detail body:' + response.read())
        result = response.read()
        jsonobj = json.loads(result)
        if jsonobj.get("error_response"):
            error = TopException()
            if jsonobj["error_response"].get(P_CODE):
                error.errorcode = jsonobj["error_response"][P_CODE]
            if jsonobj["error_response"].get(P_MSG):
                error.message = jsonobj["error_response"][P_MSG]
            if jsonobj["error_response"].get(P_SUB_CODE):
                error.subcode = jsonobj["error_response"][P_SUB_CODE]
            if jsonobj["error_response"].get(P_SUB_MSG):
                error.submsg = jsonobj["error_response"][P_SUB_MSG]
            error.application_host = response.getheader("Application-Host", "")
            error.service_host = response.getheader("Location-Host", "")
            raise error
        return jsonobj

    def getApplicationParameters(self):
        application_parameter = {}
        for key, value in self.__dict__.items():
            if not key.startswith("__") and not key in self.getMultipartParas() and not key.startswith("_RestApi__") and value is not None:
                if (key.startswith("_")):
                    application_parameter[key[1:]] = value
                else:
                    application_parameter[key] = value
        #查询翻译字典来规避一些关键字属性
        translate_parameter = self.getTranslateParas()
        for key, value in application_parameter.items():
            if key in translate_parameter:
                application_parameter[translate_parameter[key]] = application_parameter[key]
                del application_parameter[key]
        return application_parameter



'''
Created by auto_sdk on 2020.10.14
'''
from seven_top.top.api.base import RestApi
class OpentradeSpecialUsersMarkRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.hit = None
		self.item_id = None
		self.limit_num = None
		self.open_user_ids = None
		self.sku_id = None
		self.status = None

	def getapiname(self):
		return 'taobao.opentrade.special.users.mark'



'''
Created by auto_sdk on 2023.11.23
'''
from seven_top.top.api.base import RestApi
class TopConnectorPictureUploadRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.image_data = None

	def getapiname(self):
		return 'taobao.top.connector.picture.upload'

	def getMultipartParas(self):
		return ['image_data']



'''
Created by auto_sdk on 2018.07.27
'''
from seven_top.top.api.base import RestApi
class RefundRefuseRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.oid = None
		self.refund_id = None
		self.refund_phase = None
		self.refund_version = None
		self.refuse_message = None
		self.refuse_proof = None
		self.refuse_reason_id = None
		self.tid = None

	def getapiname(self):
		return 'taobao.refund.refuse'

	def getMultipartParas(self):
		return ['refuse_proof']



'''
Created by auto_sdk on 2021.12.09
'''
from seven_top.top.api.base import RestApi
class OpencrmCardResourceGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.extend_info = None
		self.file_size = None
		self.memo = None
		self.oss_key = None
		self.resource_type = None

	def getapiname(self):
		return 'taobao.opencrm.card.resource.get'



'''
Created by auto_sdk on 2020.10.28
'''
from seven_top.top.api.base import RestApi
class RefundsReceiveGetRequest(RestApi):
    def __init__(self,domain='gw.api.taobao.com',port=80):
        RestApi.__init__(self,domain, port)
        self.buyer_nick = None
        self.end_modified = None
        self.fields = None
        self.page_no = None
        self.page_size = None
        self.start_modified = None
        self.status = None
        self.type = None
        self.use_has_next = None
        self.buyer_open_uid = None

    def getapiname(self):
        return 'taobao.refunds.receive.get'



'''
Created by auto_sdk on 2023.02.09
'''
from seven_top.top.api.base import RestApi
class OpencrmCversionDigtplCreateupdateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.digital_sms_template_content_dto = None
		self.status = None
		self.template_id = None
		self.template_name = None
		self.type = None

	def getapiname(self):
		return 'taobao.opencrm.cversion.digtpl.createupdate'



'''
Author: LiuXin
Date: 2024-01-30 21:35:38
LastEditTime: 2024-01-31 16:13:04
LastEditors: LiuXin
Description: 
'''
'''
Created by auto_sdk on 2021.09.17
'''
from seven_top.top.api.base import RestApi
class TaobaoCrmMiniappConnectRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.bizValue = None
		self.buyer = None
		self.createTime = None
		self.description = None
		self.eventType = None
		self.messageId = None
		self.seller = None
		self.shopId = None
		self.target_appkey = None

	def getapiname(self):
		return 'qimen.taobao.crm.miniapp.connect'



'''
Created by auto_sdk on 2022.10.11
'''
from seven_top.top.api.base import RestApi
class CrmGradeSetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.amount = None
		self.count = None
		self.discount = None
		self.grade = None
		self.hierarchy = None

	def getapiname(self):
		return 'taobao.crm.grade.set'



'''
Created by auto_sdk on 2018.07.25
'''
from seven_top.top.api.base import RestApi
class SubuserEmployeeAddRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.department_id = None
		self.duty_id = None
		self.employee_name = None
		self.employee_nickname = None
		self.employee_num = None
		self.entry_date = None
		self.id_card_num = None
		self.leader_id = None
		self.office_phone = None
		self.personal_email = None
		self.personal_mobile = None
		self.sex = None
		self.sub_id = None
		self.work_location = None

	def getapiname(self):
		return 'taobao.subuser.employee.add'



'''
Created by auto_sdk on 2023.12.19
'''
from seven_top.top.api.base import RestApi
class PicturePicturesGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.client_type = None
		self.current_page = None
		self.deleted = None
		self.end_date = None
		self.is_https = None
		self.order_by = None
		self.page_size = None
		self.picture_category_id = None
		self.picture_id = None
		self.start_date = None
		self.start_modified_date = None
		self.title = None
		self.urls = None

	def getapiname(self):
		return 'taobao.picture.pictures.get'



'''
Created by auto_sdk on 2018.07.25
'''
from seven_top.top.api.base import RestApi
class VasOrderSearchRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.article_code = None
		self.biz_order_id = None
		self.biz_type = None
		self.end_created = None
		self.item_code = None
		self.nick = None
		self.order_id = None
		self.page_no = None
		self.page_size = None
		self.start_created = None

	def getapiname(self):
		return 'taobao.vas.order.search'



'''
Created by auto_sdk on 2020.11.26
'''
from seven_top.top.api.base import RestApi
class JstMiniappCrowdMessageSendRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.content = None
		self.crowd_code = None
		self.sign_name = None
		self.template_code = None
		self.url = None

	def getapiname(self):
		return 'taobao.jst.miniapp.crowd.message.send'



'''
Created by auto_sdk on 2020.11.19
'''
from seven_top.top.api.base import RestApi
class RefundsApplyGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.fields = None
		self.page_no = None
		self.page_size = None
		self.seller_nick = None
		self.status = None
		self.type = None

	def getapiname(self):
		return 'taobao.refunds.apply.get'



'''
Created by auto_sdk on 2018.07.25
'''
from seven_top.top.api.base import RestApi
class FuwuScoresGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.current_page = None
		self.date = None
		self.page_size = None

	def getapiname(self):
		return 'taobao.fuwu.scores.get'



'''
Created by auto_sdk on 2019.10.11
'''
from seven_top.top.api.base import RestApi
class AlibabaAliqinTaSmsNumSendRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.extend = None
		self.extend_code = None
		self.extend_name = None
		self.rec_num = None
		self.sms_free_sign_name = None
		self.sms_param = None
		self.sms_template_code = None
		self.sms_type = None

	def getapiname(self):
		return 'alibaba.aliqin.ta.sms.num.send'



'''
Created by auto_sdk on 2022.09.19
'''
from seven_top.top.api.base import RestApi
class CrmServiceChannelShortlinkCreateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.link_type = None
		self.short_link_data = None
		self.short_link_name = None

	def getapiname(self):
		return 'taobao.crm.service.channel.shortlink.create'



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2022-06-23 16:11:05
@LastEditTime: 2024-01-25 16:56:17
@LastEditors: HuangJianYi
@Description: 
"""
'''
Created by auto_sdk on 2020.12.07
'''
from seven_top.top.api.base import RestApi
class OpentradeToolsItemsQueryRequest(RestApi):
    def __init__(self, domain='gw.api.taobao.com', port=80):
        RestApi.__init__(self, domain, port)
        self.miniapp_id = None
        self.page_index = None
        self.page_size = None

    def getapiname(self):
        return 'taobao.opentrade.tools.items.query'



'''
Created by auto_sdk on 2022.09.19
'''
from seven_top.top.api.base import RestApi
class CrmMemberinfoUpdatePrivyRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.city = None
		self.close_trade_amount = None
		self.close_trade_count = None
		self.grade = None
		self.group_ids = None
		self.item_num = None
		self.ouid = None
		self.province = None
		self.status = None
		self.trade_amount = None
		self.trade_count = None

	def getapiname(self):
		return 'taobao.crm.memberinfo.update.privy'



'''
Created by auto_sdk on 2022.01.19
'''
from seven_top.top.api.base import RestApi
class MiniappWidgetTemplateInstanceUpdateRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.param_mini_app_instantiate_template_app_update_request = None

	def getapiname(self):
		return 'taobao.miniapp.widget.template.instance.update'



'''
Created by auto_sdk on 2023.12.19
'''
from seven_top.top.api.base import RestApi
class OpencrmNodeFilterRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.activity_id = None
		self.activity_inst_id = None
		self.filter_types = None
		self.filtered_node_inst_id = None
		self.node_id = None
		self.node_inst_id = None

	def getapiname(self):
		return 'taobao.opencrm.node.filter'
